@@ -1,4 +1,4 @@
-#===== Source file: ../prEntries.r on 2020-11-29
+#===== Source file: ../prEntries.r on 2021-06-02
 #-----
 
 prEntries <- function(x, style=tablesggOpt("entryStyle"), scale=1.0)
@@ -11,9 +11,10 @@ prEntries <- function(x, style=tablesggOpt("entryStyle"), scale=1.0)
   if (!inherits(style, "styleObj"))  stop("'style' is not a 'styleObj' object")
   if ((chk <- attr(style, "element_type")) != "entry")  stop(
     "'style' is not a style for entries, its 'element_type' is '", chk, "'")
-  x <- apply_style(x, style=style, replace=props_replace, scale=scale, 
+  x <- apply_style(x, style=style, replace=props_replace, 
                    setEnabled=FALSE, unstyled="base", 
-                   base_style=tablesgg::styles_pkg$entryStyle_pkg_base)
+                   base_style=styles_pkg$entryStyle_pkg_base)
+  x <- apply_scale(x, type="entry", scale=scale)
   
   x <- structure(x, row.names=x[, "id"], current_scale=scale, style=style, 
                  mergeRuns=xattr[["mergeRuns"]], 
